from setuptools import setup

setup(
	name="kenu",
	version="0.3.8",
	description="Python kenu",
	author="r4isy",
	author_email="r4isy@kenucorp.com",
	packages=["kenu"],
	install_requires=[
	'requests'
	]
	)